@@ -5,10 +5,10 @@
 
 package Device::Chip::AVR_HVSP::FuseInfo;
 
-use strict;
+use v5.26;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Carp;
 
